[−][src]Enum sysctl::CtlValue
An Enum that holds all values returned by sysctl calls.
Extract inner value with if let or match.
Example
let val_enum = sysctl::value("kern.osrevision"); if let sysctl::CtlValue::Int(val) = val_enum { println!("Value: {}", val); }
Variants
NoneNode(Vec<u8>)Int(i32)String(String)S64(u64)Struct(Vec<u8>)Uint(u32)Long(i64)Ulong(u64)U64(u64)U8(u8)U16(u16)S8(i8)S16(i16)S32(i32)U32(u32)Trait Implementations
impl PartialEq<CtlValue> for CtlValue[src]
impl PartialEq<CtlValue> for CtlValuefn eq(&self, other: &CtlValue) -> bool[src]
fn eq(&self, other: &CtlValue) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &CtlValue) -> bool[src]
fn ne(&self, other: &CtlValue) -> boolThis method tests for !=.
impl<'a> From<&'a CtlValue> for CtlType[src]
impl<'a> From<&'a CtlValue> for CtlTypeimpl PartialOrd<CtlValue> for CtlValue[src]
impl PartialOrd<CtlValue> for CtlValuefn partial_cmp(&self, other: &CtlValue) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &CtlValue) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &CtlValue) -> bool[src]
fn lt(&self, other: &CtlValue) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &CtlValue) -> bool[src]
fn le(&self, other: &CtlValue) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &CtlValue) -> bool[src]
fn gt(&self, other: &CtlValue) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &CtlValue) -> bool[src]
fn ge(&self, other: &CtlValue) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for CtlValue[src]
impl Debug for CtlValueAuto Trait Implementations