[−][src]Enum sysctl::SysctlError
Variants
NotFound(String)ExtractionErrorIoError(Error)Utf8Error(Utf8Error)NoReadAccessNoWriteAccessShortReadFields of ShortRead
read: usize | |
reported: usize |
InvalidCStr(FromBytesWithNulError)Trait Implementations
impl Debug for SysctlError[src]
impl Debug for SysctlErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for SysctlError[src]
impl Display for SysctlErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Fail for SysctlError[src]
impl Fail for SysctlErrorfn cause(&self) -> Option<&dyn Fail>[src]
fn cause(&self) -> Option<&dyn Fail>Returns a reference to the underlying cause of this failure, if it is an error that wraps other errors. Read more
fn backtrace(&self) -> Option<&Backtrace>[src]
fn backtrace(&self) -> Option<&Backtrace>Returns a reference to the Backtrace carried by this failure, if it carries one. Read more
fn context<D>(self, context: D) -> Context<D> where
D: Display + Send + Sync + 'static,
fn context<D>(self, context: D) -> Context<D> where
D: Display + Send + Sync + 'static, Provides context for this failure. Read more
fn compat(self) -> Compat<Self>
fn compat(self) -> Compat<Self>Wraps this failure in a compatibility wrapper that implements std::error::Error. Read more
fn causes(&self) -> Causes
fn causes(&self) -> CausesReturns a iterator over the causes of this Fail with itself as the first item and the root_cause as the final item. Read more
fn root_cause(&self) -> &(dyn Fail + 'static)
fn root_cause(&self) -> &(dyn Fail + 'static)Returns the "root cause" of this Fail - the last value in the cause chain which does not return an underlying cause. Read more