[−][src]Struct sysctl::CtlInfo
A structure representing control metadata
Fields
ctl_type: CtlType
The control type.
fmt: String
A string which specifies the format of the OID in a symbolic way.
This format is used as a hint by sysctl(8) to apply proper data formatting for display purposes.
Formats defined in sysctl(9):
NnodeAchar *IintIK[n]temperature in Kelvin, multiplied by an optional single digit power of ten scaling factor: 1 (default) gives deciKelvin, 0 gives Kelvin, 3 gives milliKelvinIUunsigned intLlongLUunsigned longQquad_tQUu_quad_tS,TYPEstruct TYPE structures
Methods
impl CtlInfo[src]
impl CtlInfopub fn flags(&self) -> CtlFlags[src]
pub fn flags(&self) -> CtlFlagsReturn the flags for this sysctl.
pub fn struct_type(&self) -> Option<String>[src]
pub fn struct_type(&self) -> Option<String>If the sysctl is a structure, return the structure type string.
Checks whether the format string starts with S, and returns the rest
of the format string or None if the format String does not have a struct
hint.